<?php
/**
 * @file
 * Panel for live, javascript-based Media Magnet display pane
 */

/**
 * Define the CTools plugin
 */
$plugin = array(
  // Just do this one, it is needed.
  'single' => TRUE,
  'title' => t('Media Magnet Items'),
  // Title to show up on the pane screen.
  'description' => t('Content feed from Media Magnet'),
  // Description to show up on the pane screen.
  'category' => t('Widgets'),
  // A category to put this under.
  'edit form' => 'mm_widgets_live_pane_edit_form',
  // A function that will return the settings form for the pane.
  'render callback' => 'mm_widgets_live_pane_render',
  // A function that will return the renderable content.
  // Array of defaults for the settings form.
  'defaults' => array(
    'items_query' => '',
    'items_limit' => 0,
    'items_template_key' => '',
  ),
  'all contexts' => TRUE,
  // This is NEEDED to be able to use substitution strings in your pane.
);


/**
 * Panel pane edit form callback
 */
function mm_widgets_live_pane_edit_form($form, &$form_state) {
  $conf = $form_state['conf'];

  $form['items_limit'] = array(
    '#type' => 'textfield',
    '#title' => t('Items to Show'),
    '#description' => t('Enter 0 to display all.'),
    '#default_value' => $conf['items_limit'],
    '#size' => 4,
  );

  $form['items_query'] = array(
    '#type' => 'textfield',
    '#title' => t('Item filters'),
    '#description' => 'See the <a href="http://mediamagnet.osu.edu/items" target="_blank">items explorer</a>. Ex: tags=alumni&channel_type=rss',
    '#default_value' => $conf['items_query'],
    '#maxlength' => 512,
  );

  $form['items_template_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Template key'),
    '#description' => 'Requires theme support.',
    '#default_value' => $conf['items_template_key'],
  );

  return $form;
}


/**
 * Submit function.
 *
 * Note anything in the form_state[conf] automatically gets saved.
 * Notice, the magic that automatically does that for you.
 */
function mm_widgets_live_pane_edit_form_submit(&$form, &$form_state) {
  if (isset($form_state['values']['items_limit'])) {
    $form_state['values']['items_limit'] = intval($form_state['values']['items_limit']);
  }

  // Set anything with a default value configured.
  foreach (array_keys($form_state['plugin']['defaults']) as $key) {
    if (isset($form_state['values'][$key])) {
      $form_state['conf'][$key] = $form_state['values'][$key];
    }
  }
}


/**
 * Implements hook_panels_pane_prerender().
 */
function mm_widgets_panels_pane_prerender($pane) {
  if ($pane->type == 'mm_widgets_live_pane') {
    $pane->configuration['delta'] = $pane->pid;
  }
}


/**
 * Run-time rendering of the body of the block (content type).
 *
 * See ctools_plugin_examples for more advanced info
 */
function mm_widgets_live_pane_render($subtype, $conf, $args, $contexts) {
  parse_str($conf['items_query'], $params);
  $params['per_page'] = $conf['items_limit'];

  $url = mm_query_url(_mm_add_query_params('items.json', $params));

  $container_id = 'mm_live_pane_'.$conf['delta'].'_container';
  $template_id = 'mm_live_pane_'.$conf['delta'].'_template';

  $block = new stdclass();
  $block->title = t('Media Magnet');
  $block->title_classes = array('mm-widgets-pane');
  $block->content = array();
  $block->content['#markup'] = _mm_block_content($container_id, $template_id, $conf['items_template_key']);
  $block->content['#attached']['js'][] = array(
    'data'  => _mm_widgets_js($url, $container_id, $template_id),
    'type'  => 'inline',
    'scope' => 'footer',
  );

  return $block;
}
